==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/complex/RetrieveRecordChangeHistoryResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AuditDetailCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveRecordChangeHistoryResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AuditDetailCollection")
    protected AuditDetailCollection auditDetailCollection;

    protected RetrieveRecordChangeHistoryResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse";
    }

    @Property(name="AuditDetailCollection")
    @JsonIgnore
    public Optional<AuditDetailCollection> getAuditDetailCollection() {
        return Optional.ofNullable(auditDetailCollection);
    }

    public RetrieveRecordChangeHistoryResponse withAuditDetailCollection(AuditDetailCollection auditDetailCollection) {
        RetrieveRecordChangeHistoryResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse");
        _x.auditDetailCollection = auditDetailCollection;
        return _x;
    }

    public RetrieveRecordChangeHistoryResponse withUnmappedField(String name, String value) {
        RetrieveRecordChangeHistoryResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private AuditDetailCollection auditDetailCollection;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder auditDetailCollection(AuditDetailCollection auditDetailCollection) {
            this.auditDetailCollection = auditDetailCollection;
            this.changedFields = changedFields.add("AuditDetailCollection");
            return this;
        }

        public RetrieveRecordChangeHistoryResponse build() {
            RetrieveRecordChangeHistoryResponse _x = new RetrieveRecordChangeHistoryResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse";
            _x.auditDetailCollection = auditDetailCollection;
            return _x;
        }
    }

    private RetrieveRecordChangeHistoryResponse _copy() {
        RetrieveRecordChangeHistoryResponse _x = new RetrieveRecordChangeHistoryResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.auditDetailCollection = auditDetailCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveRecordChangeHistoryResponse[");
        b.append("AuditDetailCollection=");
        b.append(this.auditDetailCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.75-sources.jar: microsoft/dynamics/crm/complex/RetrieveRecordChangeHistoryResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "AuditDetailCollection"})
@JsonInclude(Include.NON_NULL)
public class RetrieveRecordChangeHistoryResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("AuditDetailCollection")
    protected AuditDetailCollection auditDetailCollection;

    protected RetrieveRecordChangeHistoryResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse";
    }

    @Property(name="AuditDetailCollection")
    @JsonIgnore
    public Optional<AuditDetailCollection> getAuditDetailCollection() {
        return Optional.ofNullable(auditDetailCollection);
    }

    public RetrieveRecordChangeHistoryResponse withAuditDetailCollection(AuditDetailCollection auditDetailCollection) {
        RetrieveRecordChangeHistoryResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse");
        _x.auditDetailCollection = auditDetailCollection;
        return _x;
    }

    public RetrieveRecordChangeHistoryResponse withUnmappedField(String name, String value) {
        RetrieveRecordChangeHistoryResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private AuditDetailCollection auditDetailCollection;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder auditDetailCollection(AuditDetailCollection auditDetailCollection) {
            this.auditDetailCollection = auditDetailCollection;
            this.changedFields = changedFields.add("AuditDetailCollection");
            return this;
        }

        public RetrieveRecordChangeHistoryResponse build() {
            RetrieveRecordChangeHistoryResponse _x = new RetrieveRecordChangeHistoryResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveRecordChangeHistoryResponse";
            _x.auditDetailCollection = auditDetailCollection;
            return _x;
        }
    }

    private RetrieveRecordChangeHistoryResponse _copy() {
        RetrieveRecordChangeHistoryResponse _x = new RetrieveRecordChangeHistoryResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.auditDetailCollection = auditDetailCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveRecordChangeHistoryResponse[");
        b.append("AuditDetailCollection=");
        b.append(this.auditDetailCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
